@@ -1,10 +1,3 @@
-##' Generate system command to call Nonmem directly
-##' @keywords internal
-
-callNonmemDirect <- function(file.mod,path.nonmem){
-    bfile.mod <- basename(file.mod)
-    sprintf("cd %s; %s %s %s; cd -",dirname(file.mod),path.nonmem,bfile.mod,fnExtension(bfile.mod,".lst"))
-}
 
 ##' Execute Nonmem inside a dedicated directory
 ##'
@@ -135,6 +128,8 @@ NMexecDirectory <- function(file.mod,path.nonmem,files.needed,dir.data="..",syst
 
     
     ## system(path.script)
-    path.script
+    list(path.script=path.script,
+         mod.exec=file.mod.tmp,
+         dir.exec=dir.tmp)
 
 }
