@@ -69,12 +69,12 @@ adjust.method.update.inits <- function(method.update.inits,system.type,dir.psn,c
         
         cmd.update.inits <- file.psn(dir.psn,"update_inits")
         if(system.type=="linux" && suppressWarnings(system(paste(cmd.update.inits,"-h"),ignore.stdout = TRUE)!=0)){
-            stop('Attempting to use PSN\'s update_inits but it was not found. Look at the dir.psn argument or use method.update.inits="nmsim"')
+            stop('Attempting to use PSN\'s update_inits but it was not found. Look at the dir.psn argument or use the default `inits=list(method="nmsim")`')
         }
     }
 
     if(!is.null(inits$file.ext) && inits$method=="psn"){
-        stop("argument `file.ext` is not allowed when method.update.inits==\"psn\"")
+        stop("argument `file.ext` is not allowed when `inits=list(method='psn')`")
     }
 
 ### nmsim2 requires NMdata 
@@ -120,3 +120,30 @@ file.psn <- function(dir.psn,file.psn){
     if(dir.psn=="") return(file.psn)
     file.path(dir.psn,file.psn)
 }
+
+##' Simplify file paths by dropping .. and //
+##' @param path single or multiple file or dir paths as strings.
+##' @examples
+##' \dontrun{
+##' path <- c("ds/asf.t","gege/../jjj.r")
+##' NMsim:::simplePath(path)
+##' }
+##' @return Simplified paths as strings
+##' @keywords internal
+simplePath <- function(path){
+        parts.list <- strsplit(path,"/")
+
+        sapply(parts.list,function(parts){
+    simple <- character(0)
+    
+    for(p in parts){
+        if(p==""||p==".") next
+        if(p==".."){
+            if(length(simple)) simple <- head(simple,-1)
+        } else {
+            simple <- c(simple,p)
+        }
+    }
+    paste(simple,collapse="/")
+})
+}
