@@ -67,10 +67,13 @@ test_that("Basic",{
     mod <- mod[!names(mod)%in%c("THETA","OMEGA")]
     expect_equal_to_reference(mod,fileRef_a)
     
-    expect_equal_to_reference(is.na(as.numeric(theta)),fileRef_b)
+    expect_equal_to_reference(is.na(suppressWarnings(as.numeric(theta))),fileRef_b)
     ## expect_equal_to_reference(omega,fileRef_c)
 
     if(F){
+        ref_a <- readRDS(fileRef_a)
+        ref_a
+
         ref <- readRDS(fileRef)
         ref$OMEGA
         mod$OMEGA 
